# coding=utf-8

from flask_restful import Resource
from flask import current_app, request

from ...core.embedding import OpenAIEmbedding
from ...core.datasource import YHQdrantClient
from ...common import response, validator

POST_SCHEMA = {"type": "object", "properties": {"prompt": {"type": "string"}}}


class IndustrialParkResource(Resource):
    def __init__(self):
        self.embedder = OpenAIEmbedding(current_app.config["OPENAI_API_KEY"])
        self.qd_client = YHQdrantClient(
            current_app.config["QDRANT_HOST"],
            current_app.config["QDRANT_PORT"],
            self.embedder,
        )
        self.collection = current_app.config["QDRANT_COLLECTION"]
        self.park_score = float(current_app.config["PARK_SCORE"])

    @response.wrap_response
    @validator.validator(POST_SCHEMA)
    def post(self):
        data = request.get_json(force=True)
        prompt = data.get("prompt")
        try:
            raw_results = self.qd_client.search(
                prompt=prompt,
                collection_name=self.collection,
                limit=3,
            )
        except Exception as e:
            return response.InternalServerError(str(e))

        results = [item for item in raw_results if item.score >= self.park_score]
        if len(results) == 0:
            return response.NotFound("No Answer Found")

        answer = results[0].payload
        return response.OK("", answer)
