# coding=utf-8
#!/usr/bin/env python3

import click
import os
from yunheBot.create_app import create_app
from yunheBot.core.embedding import OpenAIEmbedding
from yunheBot.core.datasource import YHQdrantClient


@click.group()
def cli():
    pass


@click.command()
@click.option("--conf", type=str)
def server(conf):
    app = create_app(config_path=conf)
    host = app.config["HOST"]
    port = app.config["PORT"]
    app.run(host, port)


@click.command()
@click.option("--open_ai_key", type=str)
@click.option("--db", type=str)
@click.option("--file", type=str)
@click.option("--collection", type=str)
def upload(open_ai_key: str, db: str, filepath: str, collection: str):
    embdder = OpenAIEmbedding(open_ai_key)
    qdrant_host, qdrant_port = db.split(":")
    client = YHQdrantClient(qdrant_host, qdrant_port, embdder)

    if os.path.splitext(filepath)[1].lower() == ".csv":
        client.create_collection(collection)
        client.upload_csv(filepath, collection)
    else:
        print(f"{filepath} is not a CSV file.")
        return


cli.add_command(server)
cli.add_command(upload)
