# coding=utf-8

import csv
from qdrant_client import QdrantClient
from qdrant_client.http.models import Distance, VectorParams
from qdrant_client.http.models import PointStruct

from .embedding import Embedding
from ..util import util


@util.singleton
class YHQdrantClient:
    def __init__(self, host: str, port: int, embedder: Embedding):
        self.client = QdrantClient(host=host, port=port)
        self.embedder = embedder

    def create_collection(
        self, collection: str, size: int = 1536, distance: Distance = Distance.COSINE
    ):
        """创建数据集

        Args:
            collection (str): 集合名称
            size (int): 向量大小
            distance (QdrantClient.Distance): 损失函数
        """
        try:
            self.client.recreate_collection(
                collection_name=collection,
                vectors_config=VectorParams(size=size, distance=distance),
            )
        except Exception as e:
            raise e

    def upload_csv(self, filepath: str, collection: str):
        """导入csv数据集

        Args:
            filepath: 文件路径
        """
        with open(filepath, "r", encoding="utf-8") as f:
            csv_reader = csv.reader(f)
            count = 0
            for line in csv_reader:
                print(line)
                item = self.embedder.to_embedding(line)
                print(item)
                self.client.upsert(
                    collection_name=collection,
                    wait=True,
                    points=[
                        PointStruct(
                            id=count,
                            vector=item[2],
                            payload={"title": item[0], "text": item[1]},
                        )
                    ],
                )
                count += 1

    def search(self, prompt, collection_name, limit):
        vec = self.embedder.get_vector(prompt)
        results = self.client.search(
            collection_name=collection_name,
            query_vector=vec,
            limit=limit,
            search_params={"exact": False, "hnsw_ef": 128},
        )
        return results
