# coding=utf-8

import openai
from abc import abstractmethod, ABCMeta
from typing import List, Tuple
from ..util import util


class Embedding(metaclass=ABCMeta):
    @abstractmethod
    def generate_sample(self, items: List[str]) -> Tuple[str, str, float]:
        pass

    @abstractmethod
    def get_vector(self, prompt: str) -> float:
        pass


@util.singleton
class OpenAIEmbedding:
    def __init__(self, open_ai_key):
        self.open_ai_key = open_ai_key
        openai.api_key = open_ai_key

    def _create_embedding(self, text):
        sentence_embeddings = openai.Embedding.create(
            model="text-embedding-ada-002", input=text
        )
        return sentence_embeddings["data"][0]["embedding"]

    def generate_sample(self, items):
        vec = self._create_embedding(items[1])
        return [items[0], items[1], vec]

    def get_vector(self, prompt):
        vec = self._create_embedding(prompt)
        return vec
